### Welcome message
WELCOME_MESSAGE = """        
████████╗███████╗██████╗ ███╗   ███╗██╗██████╗ ██╗   ██╗
╚══██╔══╝██╔════╝██╔══██╗████╗ ████║██║██╔══██╗╚██╗ ██╔╝
   ██║   █████╗  ██████╔╝██╔████╔██║██║██████╔╝ ╚████╔╝ 
   ██║   ██╔══╝  ██╔══██╗██║╚██╔╝██║██║██╔═══╝   ╚██╔╝  
   ██║   ███████╗██║  ██║██║ ╚═╝ ██║██║██║        ██║   
   ╚═╝   ╚══════╝╚═╝  ╚═╝╚═╝     ╚═╝╚═╝╚═╝        ╚═╝   
                                                        
Welcome to termipy!

Author: Pratik Kumar
Version: 0.2.5
Date: 2024-10-12
Contact: pr2tik1@gmail.com

Supported Commands:
───────────────────────────────────────────────────────
echo <message>        - Prints the message to the terminal
getwd, ls             - Displays the current working directory
setwd <dir>           - Changes the working directory
typeof <file>         - Shows the type of the file or directory
clr, cls, clear       - Clears the terminal screen
tree <dir>            - Displays the directory tree
create <file>         - Creates a new file
search <file_name>    - Searches for a file by name
setpyenv <env>        - Sets up a Python environment
setrenv <env>         - Sets up an R environment
about <file>          - Displays file details
commands              - Lists all available commands
delete <file/dir>     - Deletes a file or directory
rename <file> <new>   - Renames a file or directory
diskusage             - Shows disk usage information
permissions <file>    - Displays file permissions
resource, resources, stats - Shows system resource usage
exit                  - Exits termipy
───────────────────────────────────────────────────────

Type 'help' for more details on each command.
"""
